pilot.api

Package pilot :: Package api |

# Source Code for Package pilot.api

     1  """ Abstract API Definition of the B{Pilot-API}; This is not the implementation! Please see L{pilot.impl}"""
     2
     3  from pilot.api.compute.api import PilotCompute
     4  from pilot.api.compute.api import PilotComputeService
     5  from pilot.api.compute.api import PilotComputeDescription
     6  from pilot.api.compute.api import ComputeUnit
     7  from pilot.api.compute.api import ComputeUnitService
     8  from pilot.api.compute.api import ComputeUnitDescription
     9  from pilot.api.compute.api import State
    10
    11  from pilot.api.data.api import PilotDataDescription
    12  from pilot.api.data.api import PilotData
    13  from pilot.api.data.api import PilotDataService
    14  from pilot.api.data.api import DataUnitService
    15  from pilot.api.data.api import DataUnit
    16  from pilot.api.data.api import DataUnitDescription
    17
    18  from pilot.api.api import ComputeDataService
    19  from pilot.api.api import PilotError
    20